
# Location

### Description

Represents one of a business's locations.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **String** | The location&#39;s unique ID. |  [optional]
**name** | **String** | The location&#39;s name. Location names are set by the account owner and displayed in the dashboard as the location&#39;s nickname |  [optional]
**address** | [**Address**](Address.md) | The location&#39;s physical address. |  [optional]
**timezone** | **String** | The [IANA Timezone Database](https://www.iana.org/time-zones) identifier for the location&#39;s timezone. |  [optional]
**capabilities** | [**List&lt;CapabilitiesEnum&gt;**](#List&lt;CapabilitiesEnum&gt;) | Indicates which Square features are enabled for the location. See [LocationCapability](#type-locationcapability) for possible values |  [optional]
**status** | [**StatusEnum**](#StatusEnum) | The location&#39;s status See [LocationStatus](#type-locationstatus) for possible values |  [optional]
**createdAt** | **String** | The time when the location was created, in RFC 3339 format. |  [optional]
**merchantId** | **String** | The identifier of the merchant that owns the location. |  [optional]
**country** | [**CountryEnum**](#CountryEnum) | The location&#39;s country, in ISO 3166-1-alpha-2 format. See [Country](#type-country) for possible values |  [optional]
**languageCode** | **String** | The language associated with the location in [BCP 47 format](https://tools.ietf.org/html/bcp47#appendix-A). |  [optional]
**currency** | [**CurrencyEnum**](#CurrencyEnum) | The currency used for all transactions at this location, specified in __ISO 4217 format__. For example, the currency for a location processing transactions in the United States is &#39;USD&#39;. See [Currency](#type-currency) for possible values |  [optional]
**phoneNumber** | **String** | The location&#39;s phone_number. |  [optional]
**businessName** | **String** | The location&#39;s business_name which is shown to its customers. For example, this is the name printed on its customer&#39;s receipts. |  [optional]
**type** | [**TypeEnum**](#TypeEnum) | The location&#39;s type, as set by the account owner in the Square dashboard. Typically used to indicate whether or not the location object represents a physical space like a building or mall space. See [LocationType](#type-locationtype) for possible values |  [optional]
**websiteUrl** | **String** | The location&#39;s website, as set by the account owner in the Square dashboard.  Default: none; only exists if explicitly set. |  [optional]
**businessHours** | [**BusinessHours**](BusinessHours.md) |   The hours of operation for a business location.  Default: none; only exists if explicitly set. |  [optional]
**businessEmail** | **String** | The email of the location. |  [optional]
**description** | **String** | The business description of the location. |  [optional]
**twitterUsername** | **String** | The Twitter username of the location without the &#39; |  [optional]
**instagramUsername** | **String** | The Instagram username of the location without the &#39; |  [optional]
**facebookUrl** | **String** | The Facebook profile URL of the location. The URL should begin with &#39;facebook.com/&#39;. |  [optional]
**coordinates** | [**Coordinates**](Coordinates.md) | The physical coordinates (latitude and longitude) of the location. |  [optional]


<a name="List<CapabilitiesEnum>"></a>
## Enum: List&lt;CapabilitiesEnum&gt;
Name | Value
---- | -----
PROCESSING | &quot;CREDIT_CARD_PROCESSING&quot;


<a name="StatusEnum"></a>
## Enum: StatusEnum
Name | Value
---- | -----
ACTIVE | &quot;ACTIVE&quot;
INACTIVE | &quot;INACTIVE&quot;


<a name="CountryEnum"></a>
## Enum: CountryEnum
Name | Value
---- | -----
ZZ | &quot;ZZ&quot;
AD | &quot;AD&quot;
AE | &quot;AE&quot;
AF | &quot;AF&quot;
AG | &quot;AG&quot;
AI | &quot;AI&quot;
AL | &quot;AL&quot;
AM | &quot;AM&quot;
AO | &quot;AO&quot;
AQ | &quot;AQ&quot;
AR | &quot;AR&quot;
AS | &quot;AS&quot;
AT | &quot;AT&quot;
AU | &quot;AU&quot;
AW | &quot;AW&quot;
AX | &quot;AX&quot;
AZ | &quot;AZ&quot;
BA | &quot;BA&quot;
BB | &quot;BB&quot;
BD | &quot;BD&quot;
BE | &quot;BE&quot;
BF | &quot;BF&quot;
BG | &quot;BG&quot;
BH | &quot;BH&quot;
BI | &quot;BI&quot;
BJ | &quot;BJ&quot;
BL | &quot;BL&quot;
BM | &quot;BM&quot;
BN | &quot;BN&quot;
BO | &quot;BO&quot;
BQ | &quot;BQ&quot;
BR | &quot;BR&quot;
BS | &quot;BS&quot;
BT | &quot;BT&quot;
BV | &quot;BV&quot;
BW | &quot;BW&quot;
BY | &quot;BY&quot;
BZ | &quot;BZ&quot;
CA | &quot;CA&quot;
CC | &quot;CC&quot;
CD | &quot;CD&quot;
CF | &quot;CF&quot;
CG | &quot;CG&quot;
CH | &quot;CH&quot;
CI | &quot;CI&quot;
CK | &quot;CK&quot;
CL | &quot;CL&quot;
CM | &quot;CM&quot;
CN | &quot;CN&quot;
CO | &quot;CO&quot;
CR | &quot;CR&quot;
CU | &quot;CU&quot;
CV | &quot;CV&quot;
CW | &quot;CW&quot;
CX | &quot;CX&quot;
CY | &quot;CY&quot;
CZ | &quot;CZ&quot;
DE | &quot;DE&quot;
DJ | &quot;DJ&quot;
DK | &quot;DK&quot;
DM | &quot;DM&quot;
DO | &quot;DO&quot;
DZ | &quot;DZ&quot;
EC | &quot;EC&quot;
EE | &quot;EE&quot;
EG | &quot;EG&quot;
EH | &quot;EH&quot;
ER | &quot;ER&quot;
ES | &quot;ES&quot;
ET | &quot;ET&quot;
FI | &quot;FI&quot;
FJ | &quot;FJ&quot;
FK | &quot;FK&quot;
FM | &quot;FM&quot;
FO | &quot;FO&quot;
FR | &quot;FR&quot;
GA | &quot;GA&quot;
GB | &quot;GB&quot;
GD | &quot;GD&quot;
GE | &quot;GE&quot;
GF | &quot;GF&quot;
GG | &quot;GG&quot;
GH | &quot;GH&quot;
GI | &quot;GI&quot;
GL | &quot;GL&quot;
GM | &quot;GM&quot;
GN | &quot;GN&quot;
GP | &quot;GP&quot;
GQ | &quot;GQ&quot;
GR | &quot;GR&quot;
GS | &quot;GS&quot;
GT | &quot;GT&quot;
GU | &quot;GU&quot;
GW | &quot;GW&quot;
GY | &quot;GY&quot;
HK | &quot;HK&quot;
HM | &quot;HM&quot;
HN | &quot;HN&quot;
HR | &quot;HR&quot;
HT | &quot;HT&quot;
HU | &quot;HU&quot;
ID | &quot;ID&quot;
IE | &quot;IE&quot;
IL | &quot;IL&quot;
IM | &quot;IM&quot;
IN | &quot;IN&quot;
IO | &quot;IO&quot;
IQ | &quot;IQ&quot;
IR | &quot;IR&quot;
IS | &quot;IS&quot;
IT | &quot;IT&quot;
JE | &quot;JE&quot;
JM | &quot;JM&quot;
JO | &quot;JO&quot;
JP | &quot;JP&quot;
KE | &quot;KE&quot;
KG | &quot;KG&quot;
KH | &quot;KH&quot;
KI | &quot;KI&quot;
KM | &quot;KM&quot;
KN | &quot;KN&quot;
KP | &quot;KP&quot;
KR | &quot;KR&quot;
KW | &quot;KW&quot;
KY | &quot;KY&quot;
KZ | &quot;KZ&quot;
LA | &quot;LA&quot;
LB | &quot;LB&quot;
LC | &quot;LC&quot;
LI | &quot;LI&quot;
LK | &quot;LK&quot;
LR | &quot;LR&quot;
LS | &quot;LS&quot;
LT | &quot;LT&quot;
LU | &quot;LU&quot;
LV | &quot;LV&quot;
LY | &quot;LY&quot;
MA | &quot;MA&quot;
MC | &quot;MC&quot;
MD | &quot;MD&quot;
ME | &quot;ME&quot;
MF | &quot;MF&quot;
MG | &quot;MG&quot;
MH | &quot;MH&quot;
MK | &quot;MK&quot;
ML | &quot;ML&quot;
MM | &quot;MM&quot;
MN | &quot;MN&quot;
MO | &quot;MO&quot;
MP | &quot;MP&quot;
MQ | &quot;MQ&quot;
MR | &quot;MR&quot;
MS | &quot;MS&quot;
MT | &quot;MT&quot;
MU | &quot;MU&quot;
MV | &quot;MV&quot;
MW | &quot;MW&quot;
MX | &quot;MX&quot;
MY | &quot;MY&quot;
MZ | &quot;MZ&quot;
NA | &quot;NA&quot;
NC | &quot;NC&quot;
NE | &quot;NE&quot;
NF | &quot;NF&quot;
NG | &quot;NG&quot;
NI | &quot;NI&quot;
NL | &quot;NL&quot;
NO | &quot;NO&quot;
NP | &quot;NP&quot;
NR | &quot;NR&quot;
NU | &quot;NU&quot;
NZ | &quot;NZ&quot;
OM | &quot;OM&quot;
PA | &quot;PA&quot;
PE | &quot;PE&quot;
PF | &quot;PF&quot;
PG | &quot;PG&quot;
PH | &quot;PH&quot;
PK | &quot;PK&quot;
PL | &quot;PL&quot;
PM | &quot;PM&quot;
PN | &quot;PN&quot;
PR | &quot;PR&quot;
PS | &quot;PS&quot;
PT | &quot;PT&quot;
PW | &quot;PW&quot;
PY | &quot;PY&quot;
QA | &quot;QA&quot;
RE | &quot;RE&quot;
RO | &quot;RO&quot;
RS | &quot;RS&quot;
RU | &quot;RU&quot;
RW | &quot;RW&quot;
SA | &quot;SA&quot;
SB | &quot;SB&quot;
SC | &quot;SC&quot;
SD | &quot;SD&quot;
SE | &quot;SE&quot;
SG | &quot;SG&quot;
SH | &quot;SH&quot;
SI | &quot;SI&quot;
SJ | &quot;SJ&quot;
SK | &quot;SK&quot;
SL | &quot;SL&quot;
SM | &quot;SM&quot;
SN | &quot;SN&quot;
SO | &quot;SO&quot;
SR | &quot;SR&quot;
SS | &quot;SS&quot;
ST | &quot;ST&quot;
SV | &quot;SV&quot;
SX | &quot;SX&quot;
SY | &quot;SY&quot;
SZ | &quot;SZ&quot;
TC | &quot;TC&quot;
TD | &quot;TD&quot;
TF | &quot;TF&quot;
TG | &quot;TG&quot;
TH | &quot;TH&quot;
TJ | &quot;TJ&quot;
TK | &quot;TK&quot;
TL | &quot;TL&quot;
TM | &quot;TM&quot;
TN | &quot;TN&quot;
TO | &quot;TO&quot;
TR | &quot;TR&quot;
TT | &quot;TT&quot;
TV | &quot;TV&quot;
TW | &quot;TW&quot;
TZ | &quot;TZ&quot;
UA | &quot;UA&quot;
UG | &quot;UG&quot;
UM | &quot;UM&quot;
US | &quot;US&quot;
UY | &quot;UY&quot;
UZ | &quot;UZ&quot;
VA | &quot;VA&quot;
VC | &quot;VC&quot;
VE | &quot;VE&quot;
VG | &quot;VG&quot;
VI | &quot;VI&quot;
VN | &quot;VN&quot;
VU | &quot;VU&quot;
WF | &quot;WF&quot;
WS | &quot;WS&quot;
YE | &quot;YE&quot;
YT | &quot;YT&quot;
ZA | &quot;ZA&quot;
ZM | &quot;ZM&quot;
ZW | &quot;ZW&quot;


<a name="CurrencyEnum"></a>
## Enum: CurrencyEnum
Name | Value
---- | -----
UNKNOWN_CURRENCY | &quot;UNKNOWN_CURRENCY&quot;
AED | &quot;AED&quot;
AFN | &quot;AFN&quot;
ALL | &quot;ALL&quot;
AMD | &quot;AMD&quot;
ANG | &quot;ANG&quot;
AOA | &quot;AOA&quot;
ARS | &quot;ARS&quot;
AUD | &quot;AUD&quot;
AWG | &quot;AWG&quot;
AZN | &quot;AZN&quot;
BAM | &quot;BAM&quot;
BBD | &quot;BBD&quot;
BDT | &quot;BDT&quot;
BGN | &quot;BGN&quot;
BHD | &quot;BHD&quot;
BIF | &quot;BIF&quot;
BMD | &quot;BMD&quot;
BND | &quot;BND&quot;
BOB | &quot;BOB&quot;
BOV | &quot;BOV&quot;
BRL | &quot;BRL&quot;
BSD | &quot;BSD&quot;
BTN | &quot;BTN&quot;
BWP | &quot;BWP&quot;
BYR | &quot;BYR&quot;
BZD | &quot;BZD&quot;
CAD | &quot;CAD&quot;
CDF | &quot;CDF&quot;
CHE | &quot;CHE&quot;
CHF | &quot;CHF&quot;
CHW | &quot;CHW&quot;
CLF | &quot;CLF&quot;
CLP | &quot;CLP&quot;
CNY | &quot;CNY&quot;
COP | &quot;COP&quot;
COU | &quot;COU&quot;
CRC | &quot;CRC&quot;
CUC | &quot;CUC&quot;
CUP | &quot;CUP&quot;
CVE | &quot;CVE&quot;
CZK | &quot;CZK&quot;
DJF | &quot;DJF&quot;
DKK | &quot;DKK&quot;
DOP | &quot;DOP&quot;
DZD | &quot;DZD&quot;
EGP | &quot;EGP&quot;
ERN | &quot;ERN&quot;
ETB | &quot;ETB&quot;
EUR | &quot;EUR&quot;
FJD | &quot;FJD&quot;
FKP | &quot;FKP&quot;
GBP | &quot;GBP&quot;
GEL | &quot;GEL&quot;
GHS | &quot;GHS&quot;
GIP | &quot;GIP&quot;
GMD | &quot;GMD&quot;
GNF | &quot;GNF&quot;
GTQ | &quot;GTQ&quot;
GYD | &quot;GYD&quot;
HKD | &quot;HKD&quot;
HNL | &quot;HNL&quot;
HRK | &quot;HRK&quot;
HTG | &quot;HTG&quot;
HUF | &quot;HUF&quot;
IDR | &quot;IDR&quot;
ILS | &quot;ILS&quot;
INR | &quot;INR&quot;
IQD | &quot;IQD&quot;
IRR | &quot;IRR&quot;
ISK | &quot;ISK&quot;
JMD | &quot;JMD&quot;
JOD | &quot;JOD&quot;
JPY | &quot;JPY&quot;
KES | &quot;KES&quot;
KGS | &quot;KGS&quot;
KHR | &quot;KHR&quot;
KMF | &quot;KMF&quot;
KPW | &quot;KPW&quot;
KRW | &quot;KRW&quot;
KWD | &quot;KWD&quot;
KYD | &quot;KYD&quot;
KZT | &quot;KZT&quot;
LAK | &quot;LAK&quot;
LBP | &quot;LBP&quot;
LKR | &quot;LKR&quot;
LRD | &quot;LRD&quot;
LSL | &quot;LSL&quot;
LTL | &quot;LTL&quot;
LVL | &quot;LVL&quot;
LYD | &quot;LYD&quot;
MAD | &quot;MAD&quot;
MDL | &quot;MDL&quot;
MGA | &quot;MGA&quot;
MKD | &quot;MKD&quot;
MMK | &quot;MMK&quot;
MNT | &quot;MNT&quot;
MOP | &quot;MOP&quot;
MRO | &quot;MRO&quot;
MUR | &quot;MUR&quot;
MVR | &quot;MVR&quot;
MWK | &quot;MWK&quot;
MXN | &quot;MXN&quot;
MXV | &quot;MXV&quot;
MYR | &quot;MYR&quot;
MZN | &quot;MZN&quot;
NAD | &quot;NAD&quot;
NGN | &quot;NGN&quot;
NIO | &quot;NIO&quot;
NOK | &quot;NOK&quot;
NPR | &quot;NPR&quot;
NZD | &quot;NZD&quot;
OMR | &quot;OMR&quot;
PAB | &quot;PAB&quot;
PEN | &quot;PEN&quot;
PGK | &quot;PGK&quot;
PHP | &quot;PHP&quot;
PKR | &quot;PKR&quot;
PLN | &quot;PLN&quot;
PYG | &quot;PYG&quot;
QAR | &quot;QAR&quot;
RON | &quot;RON&quot;
RSD | &quot;RSD&quot;
RUB | &quot;RUB&quot;
RWF | &quot;RWF&quot;
SAR | &quot;SAR&quot;
SBD | &quot;SBD&quot;
SCR | &quot;SCR&quot;
SDG | &quot;SDG&quot;
SEK | &quot;SEK&quot;
SGD | &quot;SGD&quot;
SHP | &quot;SHP&quot;
SLL | &quot;SLL&quot;
SOS | &quot;SOS&quot;
SRD | &quot;SRD&quot;
SSP | &quot;SSP&quot;
STD | &quot;STD&quot;
SVC | &quot;SVC&quot;
SYP | &quot;SYP&quot;
SZL | &quot;SZL&quot;
THB | &quot;THB&quot;
TJS | &quot;TJS&quot;
TMT | &quot;TMT&quot;
TND | &quot;TND&quot;
TOP | &quot;TOP&quot;
TRY | &quot;TRY&quot;
TTD | &quot;TTD&quot;
TWD | &quot;TWD&quot;
TZS | &quot;TZS&quot;
UAH | &quot;UAH&quot;
UGX | &quot;UGX&quot;
USD | &quot;USD&quot;
USN | &quot;USN&quot;
USS | &quot;USS&quot;
UYI | &quot;UYI&quot;
UYU | &quot;UYU&quot;
UZS | &quot;UZS&quot;
VEF | &quot;VEF&quot;
VND | &quot;VND&quot;
VUV | &quot;VUV&quot;
WST | &quot;WST&quot;
XAF | &quot;XAF&quot;
XAG | &quot;XAG&quot;
XAU | &quot;XAU&quot;
XBA | &quot;XBA&quot;
XBB | &quot;XBB&quot;
XBC | &quot;XBC&quot;
XBD | &quot;XBD&quot;
XCD | &quot;XCD&quot;
XDR | &quot;XDR&quot;
XOF | &quot;XOF&quot;
XPD | &quot;XPD&quot;
XPF | &quot;XPF&quot;
XPT | &quot;XPT&quot;
XTS | &quot;XTS&quot;
XXX | &quot;XXX&quot;
YER | &quot;YER&quot;
ZAR | &quot;ZAR&quot;
ZMK | &quot;ZMK&quot;
ZMW | &quot;ZMW&quot;
BTC | &quot;BTC&quot;


<a name="TypeEnum"></a>
## Enum: TypeEnum
Name | Value
---- | -----
PHYSICAL | &quot;PHYSICAL&quot;
MOBILE | &quot;MOBILE&quot;



